@@ -29,7 +29,6 @@ class _Regressor(object):
                  **kwargs):
 
         self.data = data
-        self.vdata = None
         self.regressor = regressor
         self.features = None
         self.feature_index = None
@@ -37,8 +36,6 @@ class _Regressor(object):
         self.output = None
         self.training_results = dict()
         self.fit = False
-        self.all_cv_results = None
-        self.cv_param = None
 
         self.adjustment = dict()
 
@@ -98,6 +95,7 @@ class _Regressor(object):
             return regressor_obj
 
     def grid_search_param(self,
+                          data,
                           param_dict,
                           scoring='score',
                           cv_folds=5,
@@ -106,7 +104,9 @@ class _Regressor(object):
                           allowed_grad=0.1,
                           select_perc=90):
         """
-        Method to search optimal parameters for the regressor
+        Method to search optimal parameters for the regressor. If 'select' is True, then this method
+        will return a set of parameters with the best model score.
+        :param data: dictionary with values (generated using Samples.format_data())
         :param param_dict: Dictionary of parameter grid to search for best score
         :param scoring: Score metric callable method from the regressor
         :param cv_folds: number of folds to divide the samples in
@@ -115,30 +115,45 @@ class _Regressor(object):
         :param allowed_grad: max allowable percent difference between min and max score
         :param select_perc: percentile to choose for best model selection
         """
+        self.data = data
+
         model = GridSearchCV(self.regressor,
                              param_dict,
                              scoring=scoring,
                              cv=cv_folds,
                              n_jobs=n_jobs)
 
+        if self.regressor is not None:
+
+            if 'weights' not in data:
+                model.fit(data['features'], data['labels'])
+            else:
+                model.fit(data['features'], data['labels'], sample_weight=data['weights'])
+
+        self.features = data['feature_names']
+        self.label = data['label_name']
+
         results = model.cv_results_
 
-        if select:
-            params = results['params']
-            mean_scores = results['mean_test_score']
-            std_scores = results['std_test_score']
-            ranks = results['rank_test_scores']
+        params = results['params']
+        scores_mean = results['mean_test_score']
+        scores_sd = results['std_test_score']
+        ranks = results['rank_test_scores']
 
-            grad_cond = (std_scores.max() - std_scores.min()) / std_scores.max() <= allowed_grad
+        if select:
+            grad_cond = (scores_sd.max() - scores_sd.min()) / scores_sd.max() <= allowed_grad
             if not grad_cond:
-                param = params[np.where(mean_scores == np.percentile(mean_scores,
+                param = params[np.where(scores_mean == np.percentile(scores_mean,
                                                                      select_perc,
                                                                      interpolation='nearest'))]
             else:
                 param = params[np.where(ranks == 1)]
-            self.cv_param = param
+            return param
         else:
-            return results
+            return {'params': params,
+                    'scores_mean': scores_mean,
+                    'scores_sd': scores_sd,
+                    'rank': ranks}
 
     @staticmethod
     def get_defaults(**kwargs):
